@@ -1071,7 +1071,8 @@ tsh_blame_func2 (void *baton, apr_int64_t line_no, svn_revnum_t revision, const
 {
   apr_time_t date_val;
   gchar *date_str = NULL;
-	TshBlameDialog *dialog = TSH_BLAME_DIALOG (baton);
+  struct tsh_blame_baton *blame_baton = baton;
+  TshBlameDialog *dialog = blame_baton->dialog;
 
   if(date)
   {
@@ -1090,6 +1091,17 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 	return SVN_NO_ERROR;
 }
 
+svn_error_t *
+tsh_blame_func4   (void *baton, apr_int64_t line_no, svn_revnum_t revision, apr_hash_t *revprops, svn_revnum_t merged_revision, apr_hash_t *merged_rev_props, const char *merged_path, const svn_string_t *line, svn_boolean_t local_change, apr_pool_t *pool)
+{
+  struct tsh_blame_baton *blame_baton = baton;
+  /* svn_string_t guarantees NULL terminated string */
+  return tsh_blame_func3(baton,
+    blame_baton->start_revnum, blame_baton->end_revnum,
+    line_no, revision, revprops, merged_revision, merged_rev_props,
+    merged_path, line->data, local_change, pool);
+}
+
 svn_error_t *
 tsh_blame_func3 (void *baton, svn_revnum_t start_revision, svn_revnum_t end_revision, apr_int64_t line_no, svn_revnum_t revision, apr_hash_t *revprops, svn_revnum_t merged_revision, apr_hash_t *merged_rev_props, const char *merged_path, const char *line, svn_boolean_t local_change, apr_pool_t *pool)
 {
@@ -1097,7 +1109,8 @@ tsh_blame_func3 (void *baton, svn_revnum_t start_revision, svn_revnum_t end_revi
   svn_string_t *value;
   gchar *author = NULL;
   gchar *date = NULL;
-  TshBlameDialog *dialog = TSH_BLAME_DIALOG (baton);
+  struct tsh_blame_baton *blame_baton = baton;
+  TshBlameDialog *dialog = blame_baton->dialog;
 
   value = apr_hash_get(revprops, SVN_PROP_REVISION_AUTHOR, APR_HASH_KEY_STRING);
   if(value)
